
const GObject = imports.gi.GObject;
const Gtk = imports.gi.Gtk;
const Lang = imports.lang;

const Gettext = imports.gettext.domain('disable-ubuntu-dock');
const _ = Gettext.gettext;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Convenience = Me.imports.convenience;

//-----------------------------------------------

function init() {
    Convenience.initTranslations();
}

//-----------------------------------------------

const disableDefaultExtensionsSettingsWidget = new GObject.Class({
    Name: 'disableDefaultExtensions.Prefs.Widget',
    GTypeName: 'disableDefaultExtensionsPrefsWidget',
    Extends: Gtk.Box,

    _init: function(params) {
		this.parent(params);
        this.margin = 30;
        this.spacing = 25;
        this.fill = true;
        this.set_orientation(Gtk.Orientation.VERTICAL);
        
		let labelMain = '<b>' + _("Modifications will be effective after reloading the extension.") + '</b>';
		this.add(new Gtk.Label({ label: labelMain, use_markup: true, halign: Gtk.Align.START }));
		
		this._settings = Convenience.getSettings('org.gnome.shell.extensions.disable-default-extensions');
		
		let _extensionsToDisable = this._settings.get_strv('extensions');
		
		let _dUbuntuDock = ( _extensionsToDisable[0] != '' );
		let _dUbuntuAppindicators = ( _extensionsToDisable[1] != '' );
		let _dCustom = _extensionsToDisable[2];
		
		//----------------------------
		
		let DockCheckButton = new Gtk.CheckButton({label:_("Disable Ubuntu Dock")});

		DockCheckButton.connect('toggled', Lang.bind(this, function(b) {
			if(b.get_active()) {
				_extensionsToDisable[0] = 'ubuntu-dock@ubuntu.com';
			} else {
				_extensionsToDisable[0] = '';
			}
			this._settings.set_strv('extensions', _extensionsToDisable);
		}));
		
		DockCheckButton.set_active(_dUbuntuDock);

    	this.add(DockCheckButton);
		
		//------------
		
		let AppindCheckButton = new Gtk.CheckButton({label:_("Disable Ubuntu Appindicators ")});
		
		AppindCheckButton.connect('toggled', Lang.bind(this, function(b) {
			if(b.get_active()) {
				_extensionsToDisable[1] = 'ubuntu-appindicators@ubuntu.com';
			} else {
				_extensionsToDisable[1] = '';
			}
			this._settings.set_strv('extensions', _extensionsToDisable);
		}));
		
		AppindCheckButton.set_active( _dUbuntuAppindicators );

    	this.add(AppindCheckButton);
    	
    	//-----------
    	
		let box3 = new Gtk.Box({orientation: Gtk.Orientation.VERTICAL});
		let box2 = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
		
		box3.fill = true;
		box2.fill = true;
		
		this.entry = new Gtk.Entry({hexpand: true});
		this.entry.set_text( _dCustom );
		
		let button_r = new Gtk.Button({label: 'OK'});
		
		button_r.connect('clicked', Lang.bind(this, function() {
			_extensionsToDisable[2] = this.entry.get_text();
			this._settings.set_strv('extensions', _extensionsToDisable);
		}));
		
		let label2 = new Gtk.Label({ label: _("Other extension (UUID):"), halign: Gtk.Align.START });
		box3.add(label2);
		
		box2.add(this.entry);
		box2.add(button_r);
		
		box3.add(box2);
		
		this.add(box3);
	}
});

//-----------------------------------------------

function buildPrefsWidget() {
    let widget = new disableDefaultExtensionsSettingsWidget();
    widget.show_all();
	
    return widget;
}
